Learn R Programming

highlight (version 0.2-0)

translator_latex: LaTeX translator

Description

This function translates character vectors so that they nicely print in LaTeX. In particular this uses latex boxes.

Usage

translator_latex(x)

Arguments

x
text to translate

Value

  • translated text

See Also

the latex renderer: renderer_latex uses this translator.

Examples

Run this code
# the code is probably the best description of what this does
translator_latex
translator_latex( "#<" )

Run the code above in your browser using DataLab