Learn R Programming

highlight (version 0.4.2)

styler_assistant_latex: latex styler assistant

Description

This function takes the output of the css.parser and produces latex style definitions from it.

Usage

styler_assistant_latex(x)

Arguments

x
output from css.parser

Value

  • a vector of latex style definitions corresponding to (a subset of) the output of the parser

Details

The function create a new latex command for each css declaration, i.e. each item of the list x it is passed.

The assistant currently honours the following css settings: color, text-decoration:underline, font-weight:bold[er] and font-style:italic

See Also

styler

Examples

Run this code
styler( "default", "sty", styler_assistant_latex )
css.out <- css.parser( getStyleFile( "default" ) )
styler_assistant_latex( css.out )

Run the code above in your browser using DataLab